<div align="center">
 <h1>⚗️ distilabel</h1>
 <p><em>AI Feedback (AIF) framework in Python</em></p>
</div>

## What's `distilabel`?

`distilabel` is a Python framework for building datasets with AI for LLM fine-tuning, evaluation, and alignment. 

It gives an extensible and scalable framework for AI Feedback (AIF), Language Model (LM) alignment and model distillation, building on state of the art approaches such as UltraFeedback or JudgeLM.
